==> polycule-v0.0.1.tar.gz: polycule-v0.0.1/linux/polycule_client.cc <==
#include "polycule_client.h"

#include <flutter_linux/flutter_linux.h>
#ifdef GDK_WINDOWING_X11
#include <gdk/gdkx.h>
#endif

#include "flutter/generated_plugin_registrant.h"

struct _PolyculeClient {
  GtkApplication parent_instance;
  char** dart_entrypoint_arguments;
};

G_DEFINE_TYPE(PolyculeClient, polycule_client, GTK_TYPE_APPLICATION)

// Implements GApplication::activate.
static void polycule_client_activate(GApplication* application) {
  PolyculeClient* self = POLYCULE_CLIENT(application);

  GList* windows = gtk_application_get_windows(GTK_APPLICATION(application));
  if (windows) {
    gtk_window_present(GTK_WINDOW(windows->data));
    return;
  }
  GtkWindow* window =
      GTK_WINDOW(gtk_application_window_new(GTK_APPLICATION(application)));

  // Use a header bar when running in GNOME as this is the common style used
  // by applications and is the setup most users will be using (e.g. Ubuntu
  // desktop).
  // If running on X and not using GNOME then just use a traditional title bar
  // in case the window manager does more exotic layout, e.g. tiling.
  // If running on Wayland assume the header bar will work (may need changing
  // if future cases occur).
  gboolean use_header_bar = FALSE;
#ifdef GDK_WINDOWING_X11
  GdkScreen* screen = gtk_window_get_screen(window);
  if (GDK_IS_X11_SCREEN(screen)) {
    const gchar* wm_name = gdk_x11_screen_get_window_manager_name(screen);
    if (g_strcmp0(wm_name, "GNOME Shell") != 0) {
      use_header_bar = FALSE;
    }
  }
#endif
  if (use_header_bar) {
    GtkHeaderBar* header_bar = GTK_HEADER_BAR(gtk_header_bar_new());
    gtk_widget_show(GTK_WIDGET(header_bar));
    gtk_header_bar_set_title(header_bar, "< polycule >");
    gtk_header_bar_set_show_close_button(header_bar, TRUE);
    gtk_window_set_titlebar(window, GTK_WIDGET(header_bar));
  } else {
    gtk_window_set_title(window, "< polycule >");
  }

  gtk_window_set_default_size(window, 1280, 720);
  gtk_widget_show(GTK_WIDGET(window));

  g_autoptr(FlDartProject) project = fl_dart_project_new();
  fl_dart_project_set_dart_entrypoint_arguments(project, self->dart_entrypoint_arguments);

  FlView* view = fl_view_new(project);
  gtk_widget_show(GTK_WIDGET(view));
  gtk_container_add(GTK_CONTAINER(window), GTK_WIDGET(view));

  fl_register_plugins(FL_PLUGIN_REGISTRY(view));

  gtk_widget_grab_focus(GTK_WIDGET(view));
}

// Implements GApplication::local_command_line.
static gboolean polycule_client_local_command_line(GApplication* application, gchar*** arguments, int* exit_status) {
  PolyculeClient* self = POLYCULE_CLIENT(application);
  // Strip out the first argument as it is the binary name.
  self->dart_entrypoint_arguments = g_strdupv(*arguments + 1);

  g_autoptr(GError) error = nullptr;
  if (!g_application_register(application, nullptr, &error)) {
     g_warning("Failed to register: %s", error->message);
     *exit_status = 1;
     return TRUE;
  }

  g_application_activate(application);
  *exit_status = 0;

  return FALSE;
}

// Implements GApplication::startup.
static void polycule_client_startup(GApplication* application) {
  //PolyculeClient* self = POLYCULE_CLIENT(object);

  // Perform any actions required at application startup.

  G_APPLICATION_CLASS(polycule_client_parent_class)->startup(application);
}

// Implements GApplication::shutdown.
static void polycule_client_shutdown(GApplication* application) {
  //PolyculeClient* self = POLYCULE_CLIENT(object);

  // Perform any actions required at application shutdown.

  G_APPLICATION_CLASS(polycule_client_parent_class)->shutdown(application);
}

// Implements GObject::dispose.
static void polycule_client_dispose(GObject* object) {
  PolyculeClient* self = POLYCULE_CLIENT(object);
  g_clear_pointer(&self->dart_entrypoint_arguments, g_strfreev);
  G_OBJECT_CLASS(polycule_client_parent_class)->dispose(object);
}

static void polycule_client_class_init(PolyculeClientClass* klass) {
  G_APPLICATION_CLASS(klass)->activate = polycule_client_activate;
  G_APPLICATION_CLASS(klass)->local_command_line = polycule_client_local_command_line;
  G_APPLICATION_CLASS(klass)->startup = polycule_client_startup;
  G_APPLICATION_CLASS(klass)->shutdown = polycule_client_shutdown;
  G_OBJECT_CLASS(klass)->dispose = polycule_client_dispose;
}

static void polycule_client_init(PolyculeClient* self) {}

PolyculeClient* polycule_client_new() {
  return POLYCULE_CLIENT(g_object_new(polycule_client_get_type(),
                                     "application-id", APPLICATION_ID,
                                     "flags", G_APPLICATION_HANDLES_COMMAND_LINE | G_APPLICATION_HANDLES_OPEN,
                                     nullptr));
}

==> polycule-v0.0.6.tar.gz: polycule-v0.0.6/linux/polycule_client.cc <==
#include "polycule_client.h"

#include <flutter_linux/flutter_linux.h>
#ifdef GDK_WINDOWING_X11
#include <gdk/gdkx.h>
#endif

#include "flutter/generated_plugin_registrant.h"

struct _PolyculeClient {
  GtkApplication parent_instance;
  char** dart_entrypoint_arguments;
};

G_DEFINE_TYPE(PolyculeClient, polycule_client, GTK_TYPE_APPLICATION)

// Implements GApplication::activate.
static void polycule_client_activate(GApplication* application) {
  PolyculeClient* self = POLYCULE_CLIENT(application);

  GList* windows = gtk_application_get_windows(GTK_APPLICATION(application));
  if (windows) {
    gtk_window_present(GTK_WINDOW(windows->data));
    return;
  }

  GtkWindow* window =
      GTK_WINDOW(gtk_application_window_new(GTK_APPLICATION(application)));

  // Use a header bar when running in GNOME as this is the common style used
  // by applications and is the setup most users will be using (e.g. Ubuntu
  // desktop).
  // If running on X and not using GNOME then just use a traditional title bar
  // in case the window manager does more exotic layout, e.g. tiling.
  // If running on Wayland assume the header bar will work (may need changing
  // if future cases occur).
  gboolean use_header_bar = FALSE;
#ifdef GDK_WINDOWING_X11
  GdkScreen* screen = gtk_window_get_screen(window);
  if (GDK_IS_X11_SCREEN(screen)) {
    const gchar* wm_name = gdk_x11_screen_get_window_manager_name(screen);
    if (g_strcmp0(wm_name, "GNOME Shell") != 0) {
      use_header_bar = FALSE;
    }
  }
#endif
  if (use_header_bar) {
    GtkHeaderBar* header_bar = GTK_HEADER_BAR(gtk_header_bar_new());
    gtk_widget_show(GTK_WIDGET(header_bar));
    gtk_header_bar_set_title(header_bar, "< polycule >");
    gtk_header_bar_set_show_close_button(header_bar, TRUE);
    gtk_window_set_titlebar(window, GTK_WIDGET(header_bar));
  } else {
    gtk_window_set_title(window, "< polycule >");
  }

  gtk_window_set_default_size(window, 1280, 720);
  gtk_widget_show(GTK_WIDGET(window));

  g_autoptr(FlDartProject) project = fl_dart_project_new();
  fl_dart_project_set_dart_entrypoint_arguments(project, self->dart_entrypoint_arguments);

  FlView* view = fl_view_new(project);
  gtk_widget_show(GTK_WIDGET(view));
  gtk_container_add(GTK_CONTAINER(window), GTK_WIDGET(view));

  fl_register_plugins(FL_PLUGIN_REGISTRY(view));

  gtk_widget_grab_focus(GTK_WIDGET(view));
}

// Implements GApplication::command_line.
static gint polycule_client_command_line(GApplication* application, GApplicationCommandLine* command_line) {
  PolyculeClient* self = POLYCULE_CLIENT(application);

  gchar **arguments = g_application_command_line_get_arguments(command_line, nullptr);
  // Strip out the first argument as it is the binary name.
  self->dart_entrypoint_arguments = g_strdupv(arguments + 1);

  g_autoptr(GError) error = nullptr;
  if (!g_application_register(application, nullptr, &error)) {
     g_warning("Failed to register: %s", error->message);
     return 1;
  }

  g_application_activate(application);

  return 0;
}

// Implements GObject::dispose.
static void polycule_client_dispose(GObject* object) {
  PolyculeClient* self = POLYCULE_CLIENT(object);
  g_clear_pointer(&self->dart_entrypoint_arguments, g_strfreev);
  G_OBJECT_CLASS(polycule_client_parent_class)->dispose(object);
}

static void polycule_client_class_init(PolyculeClientClass* klass) {
  G_APPLICATION_CLASS(klass)->activate = polycule_client_activate;
  G_APPLICATION_CLASS(klass)->command_line = polycule_client_command_line;
  G_OBJECT_CLASS(klass)->dispose = polycule_client_dispose;
}

static void polycule_client_init(PolyculeClient* self) {}

PolyculeClient* polycule_client_new() {
  return POLYCULE_CLIENT(g_object_new(polycule_client_get_type(),
                                     "application-id", APPLICATION_ID,
                                     "flags", G_APPLICATION_HANDLES_COMMAND_LINE | G_APPLICATION_HANDLES_OPEN,
                                     nullptr));
}
